@@ -58,6 +58,12 @@ class MenuBar(QtGui.QMenuBar):
         ## Quit
         self.quit = self.addAction(self.tr("&Quit"))
 
+    def retranslate(self):
+        self.preference.setText(self.tr("&Preferences"))
+        self.add_friend.setText(self.tr("Add &friend"))
+        self.about.setText(self.tr("&About"))
+        self.quit.setText(self.tr("&Quit"))
+
 
 class Central_widget(QtGui.QWidget):
     def __init__(self, parent):
@@ -65,8 +71,8 @@ class Central_widget(QtGui.QWidget):
         self.parent = parent
 
         # Load gui items
-        self.bonjour_users_label = QtGui.QLabel('Select your Bonjour '
-                                                'contact id :')
+        self.bonjour_users_label = QtGui.QLabel(self.tr('Select your Bonjour '
+                                                'contact id :'))
         self.bonjour_users_label.setFixedHeight(50)
         self.bonjour_users = QtGui.QComboBox()
         icon = QtGui.QIcon('/usr/share/icons/hicolor/48x48/hildon'
@@ -75,7 +81,7 @@ class Central_widget(QtGui.QWidget):
         self.reload_bonjour_users_button.setIcon(icon)
         self.reload_bonjour_users_button.setFixedWidth(80)
         self.empty = QtGui.QLabel('')
-        self.friend_list_label = QtGui.QLabel('Friend list :')
+        self.friend_list_label = QtGui.QLabel(self.tr('Friend list :'))
         self.friends_list = Friend_list_widget(self)
         mainLayout = QtGui.QGridLayout()
         mainLayout.addWidget(self.bonjour_users_label, 0, 0, 1, 2)
@@ -89,6 +95,11 @@ class Central_widget(QtGui.QWidget):
         mainLayout.setRowStretch(0, 0)
         self.setLayout(mainLayout)
 
+    def retranslate(self):
+        self.bonjour_users_label.setText(self.tr('Select your Bonjour '
+                                                'contact id :'))
+        self.friend_list_label.setText(self.tr('Friend list :'))
+
     def reload_contacts(self):
         self.parent.main_window.setAttribute(
                                     QtCore.Qt.WA_Maemo5ShowProgressIndicator,
@@ -97,11 +108,11 @@ class Central_widget(QtGui.QWidget):
         last_authorized_bonjour_contact = config.read_last_authorized_bonjour_contact()
 
         self.parent.main_window.repaint()
-        banner_notification("Looking for Bonjour contacts ...")
+        banner_notification(self.tr("Looking for Bonjour contacts ..."))
         self.parent.bonjour_users = list_presence_users()
         self.bonjour_users.clear()
         if len(self.parent.bonjour_users) == 0:
-            banner_notification("No Bonjour contacts found !")
+            banner_notification(self.tr("No Bonjour contacts found !"))
         else:
             node_friend_list = [f.node for f in 
                                 self.parent.scheduler.friend_list]
@@ -119,7 +130,7 @@ class Central_widget(QtGui.QWidget):
                 logger.debug("Last Bonjour contact found: %s, we select it" % last_authorized_bonjour_contact)
                 self.bonjour_users.setCurrentIndex(index)
 
-            banner_notification("Bonjour contacts loaded !")
+            banner_notification(self.tr("Bonjour contacts loaded !"))
 
         self.parent.main_window.setAttribute(
                                     QtCore.Qt.WA_Maemo5ShowProgressIndicator,
@@ -127,12 +138,13 @@ class Central_widget(QtGui.QWidget):
 
 
 class Ui_MainWindow(QtCore.QObject):
-    def __init__(self, app):
+    def __init__(self, app, translator):
         QtCore.QObject.__init__(self)
         self.app = app
         self.friend_list = []
         self.bonjour_auth_user = ''
         self.bonjour_users = {}
+        self.translator = translator
 
     def setupUi(self, main_window):
         self.main_window = main_window
@@ -201,6 +213,7 @@ class Ui_MainWindow(QtCore.QObject):
     def add_friend(self):
         friends_dialog = QtGui.QInputDialog(self.main_window)
         friends_dialog.setComboBoxEditable(0)
+        friends_dialog.setOkButtonText(self.tr("Done"))
         db = bsddb.hashopen('/home/user/.osso-abook/db/addressbook.db', 'r')
         friend_list = {}
         old_friend_list = [f.fullname for f in self.scheduler.friend_list]
@@ -236,15 +249,15 @@ class Ui_MainWindow(QtCore.QObject):
 
         q_friend_list = QtCore.QStringList(sorted(q_friend_dict.keys()))
         friends_dialog.setComboBoxItems(q_friend_list)
-        friends_dialog.setWindowTitle("Add a friend")
-        friends_dialog.setLabelText("Select a friend")
+        friends_dialog.setWindowTitle(self.tr("Add a friend"))
+        friends_dialog.setLabelText(self.tr("Select a friend"))
         ret = friends_dialog.exec_()
 
         if ret == 0:
             logger.debug("Dialog not confirmed")
             return
 
-        raw_name = str(friends_dialog.textValue())
+        raw_name = unicode(friends_dialog.textValue())
         number = q_friend_dict[raw_name]
         select_friend = friend_list[number]
         bonjour_auth_username = str(self.bonjour_auth_user)
@@ -268,8 +281,8 @@ class Ui_MainWindow(QtCore.QObject):
         icon = QtGui.QIcon('/usr/share/icons/hicolor/48x48/hildon'
                            '/general_refresh.png')
         vars = {}
-        vars['version'] = "1.6.8"
-        message = QtCore.QString("""<center><h2>HeySms</h2></center>"""
+        vars['version'] = "1.7.1"
+        message = QtCore.QString(self.tr("""<center><h2>HeySms</h2></center>"""
                                  """<center>Version: %(version)s</center>"""
                                  """<br/>Visite web site: <a href="http://talk.maemo.org/showthread.php?t=84705">Here</a> """
                                  """<br/>Report bugs: <a href="https://github.com/titilambert/HeySms/issues?milestone=&page=1&state=open">Here</a> """
@@ -278,9 +291,10 @@ class Ui_MainWindow(QtCore.QObject):
                                  """<li>My Doudoune</li>"""
                                  """<li>David Rodigari</li>"""
                                  """<li>Oskar Welzl</li>"""
+                                 """<li>Stefan Siegl</li>"""
                                  """</ul>"""
-                                 """ """ % vars)
-        QtGui.QMessageBox.about(self.main_window, "About", message)
+                                 """ """ % vars))
+        QtGui.QMessageBox.about(self.main_window, self.tr("About"), message)
 
 
 def main():
@@ -307,6 +321,7 @@ def main():
                           action="store_true",
                           default='False', help="Debug mode")
 
+    translator = QtCore.QTranslator()
     app = QtGui.QApplication(sys.argv)
 #    app.setOrganizationName("HeySms")
 #    app.setOrganizationDomain("HeySms")
@@ -314,10 +329,11 @@ def main():
     (options, args) = opt_parser.parse_args([str(i) for i in app.arguments()])
     logger.set_debug(options.debug_mode)
     
-    main_window = QtGui.QMainWindow()
-    ui = Ui_MainWindow(app)
-    ui.setupUi(main_window)
+    ui = Ui_MainWindow(app, translator)
     config.parent = ui
+    config.set_language(starting=True)
+    main_window = QtGui.QMainWindow()
+    ui.setupUi(main_window)
 
     ui.call_listener = Call_listener(ui)
     ui.call_listener.start()
@@ -331,6 +347,7 @@ def main():
 
     main_window.setWindowTitle("HeySms")
     main_window.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
+    main_window.app = app
     main_window.show()
     main_window.repaint()
     ui.central_widget.repaint()
