@@ -81,7 +81,7 @@ class Config(QtCore.QSettings):
         if not default_lang in languages.values():
             default_lang = "en"
         self.language = self.value("language", default_lang).toString()
-        print "self.language", self.language
+        logger.debug("Language: %s" % self.language)
 
     def update_last_authorized_user(self, contact):
         self.last_authorized_bonjour_contact = contact
