@@ -37,6 +37,8 @@ import avahi
 
 import pybonjour
 
+from PyQt4 import QtCore
+
 
 def search_contact_by_number(phone_number):
     db = bsddb.hashopen('/home/user/.osso-abook/db/addressbook.db', 'r')
@@ -94,22 +96,6 @@ def resolve(name, interface):
         #print args[0]
         ml.quit()
 
-    def myhandler(interface, protocol, name, stype, domain, flags):
-        # print "Found service '%s' type '%s' domain '%s' " % (name,
-        #                                                      stype,
-        #                                                      domain)
-
-        print flags
-        print avahi.LOOKUP_RESULT_LOCAL
-        print 'WWWW'
-        if flags & avahi.LOOKUP_RESULT_LOCAL:
-                # local service, skip
-                ml.quit()
-
-        server.ResolveService(interface, protocol, name, stype,
-            domain, avahi.PROTO_UNSPEC, dbus.UInt32(0),
-            reply_handler=service_resolved, error_handler=print_error)
-
     loop = DBusGMainLoop()
 
     bus = dbus.SystemBus(mainloop=loop)
@@ -122,7 +108,7 @@ def resolve(name, interface):
                           name,
                           '_presence._tcp',
                           'local',
-                          avahi.PROTO_UNSPEC,
+                          avahi.PROTO_INET,
                           dbus.UInt32(0),
                           reply_handler=service_resolved,
                           error_handler=print_error)
@@ -215,7 +201,7 @@ def list_presence_users(regtype='_presence._tcp', nb_try=10):
 def banner_notification(message):
     osso_c = osso.Context("heysms_notif", "0.0.1", False)
     note = osso.SystemNote(osso_c)
-    note.system_note_infoprint(message)
+    note.system_note_infoprint(unicode(message).encode("utf8"))
 
 
 class Log(object):
